@@ -36,6 +36,8 @@ extern list Counters, UserLists;
 
 #define TABPOS_COUNT	40
 
+const unsigned char UTF8Head[3] = {0xEF, 0xBB, 0xBF};
+
 /// Attribute for each line of conferted text.
 class TLinePass2
 {
@@ -134,7 +136,7 @@ static bool SectionOrEmpty(const char *str)
               return false;
       case 10:if(str[i]=='n') {s=11; break;}
               return false;
-      case 11:if(str[i]=='{')
+      case 11:if(str[i]=='{')			// \subsection{}
                 {
                 int level = 0;
                 while(str[i+1]!='}' || level>0)
@@ -306,10 +308,12 @@ void TconvertedPass2::LatexHead(void)
 int i;
 string TeX_RelativeFigDir;
 
-  fprintf(this->LaTeX,_("%% This file was created by the WP2LaTeX program version: %s \n"), VersionWP2L );
+  if(CodePage==UTF8)
+      fwrite(UTF8Head,1,3,LaTeX);
+  fprintf(LaTeX, _("%% This file has been created by the WP2LaTeX program version: %s \n"), VersionWP2L );
   if(LaTeX_Version<0x300)
     {
-    fprintf(this->LaTeX, "\\documentstyle[11pt,");
+    fprintf(LaTeX, "\\documentstyle[11pt,");
     if(Accents>=1)  fprintf(this->LaTeX, "accents,");
     if(Amssymb>=1)  fprintf(this->LaTeX, "amssymb,");
     if(AmsMath>=1)   fprintf(this->LaTeX, "amsmath,");
@@ -365,13 +369,14 @@ string TeX_RelativeFigDir;
     if(CPStyles) switch(CodePage)
 	{
 	case 0: break;
-	case ISO8859_1:fprintf(this->LaTeX, "\\usepackage[latin1]{inputenc}\n");
+	case ISO8859_1:fprintf(LaTeX, "\\usepackage[latin1]{inputenc}\n");
 		       break;
-	case ISO8859_2:fprintf(this->LaTeX, "\\usepackage[latin2]{inputenc}\n");
+	case ISO8859_2:fprintf(LaTeX, "\\usepackage[latin2]{inputenc}\n");
 		       break;
-	case KOI8R:    fprintf(this->LaTeX, "\\usepackage[koi8-r]{inputenc}\n");
+	case KOI8R:    fprintf(LaTeX, "\\usepackage[koi8-r]{inputenc}\n");
 		       break;
-        case UTF8:     fprintf(this->LaTeX, "\\usepackage[utf8x]{inputenc}\n");
+        case UTF8:     fprintf(LaTeX, "\\usepackage[utf8x]{inputenc}\n");
+                       fprintf(LaTeX, "\\usepackage[T1,T2A]{fontenc}\n");
 		       break;
 	default:fprintf(this->LaTeX, "\\usepackage[cp%d]{inputenc}\n", CodePage);
 		break;
@@ -1101,6 +1106,24 @@ while(i<length(s))
 	   if(s[i]=='h')	 //ignore \headtext{\anything}
 		 {
 		 i++;
+		 if(s[i]=='y')
+		 {
+		   i++;
+		   if(s[i++]!='p') return(0);
+		   if(s[i++]!='h') return(0);
+		   if(s[i++]!='e') return(0);
+		   if(s[i++]!='n') return(0);
+		   if(s[i++]!='p') return(0);
+		   if(s[i++]!='e') return(0);
+		   if(s[i++]!='n') return(0);
+		   if(s[i++]!='a') return(0);
+		   if(s[i++]!='l') return(0);
+		   if(s[i++]!='t') return(0);
+		   if(s[i++]!='y') return(0);
+		   while(isspace(s[i])) i++;
+		   while(isdigit(s[i])) i++;
+		   continue;
+		 }
 		 if(s[i++]!='e') return(0);
 		 if(s[i++]!='a') return(0);
 		 if(s[i++]!='d') return(0);
@@ -1607,7 +1630,7 @@ TconvertedPass2 cq2;
         int pos = -1;
         for(i=length(cq2.Lines[cq2.next].Lstring)-1; i>=1; i--)
             {
-            char ch = (cq2.Lines[cq2.next].Lstring)[i];
+            unsigned char ch = (cq2.Lines[cq2.next].Lstring)[i];
             if(isspace(ch))
                 {
                 pos = i;
@@ -1782,9 +1805,9 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 	 HelpS = StrStr((*aLineStr)(), "@{\\");   /*ignore tabular formater @{...}*/
 	 if(HelpS==NULL)
 	   {
-	   for(i=0;i<sizeof(GenericStr)/sizeof(char*);i++)
+	   for(i=0; i<sizeof(GenericStr)/sizeof(char*); i++)
 	     {
-	     HelpS = (*aLineStr)();   /**/
+	     HelpS = (*aLineStr)();
 	     do {
 	        HelpS = TryToRemoveGeneric(HelpS,GenericStr[i]);
 	        } while(HelpS!=NULL);
@@ -1806,7 +1829,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 
 	 if(cq2.Lines[cq2.cur].envir=='B')
 		{
-		HelpS=StrStr((*aLineStr)(), "\\penalty-10001");
+		HelpS = StrStr((*aLineStr)(), "\\penalty-10001");
 		if(HelpS!=NULL)
 		  {
 		  if(OptimizeMultiRows(*aLineStr))
@@ -1816,10 +1839,12 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 		}
 
 	 if(length(*aLineStr)>0)
-	   if((i=fputs((*aLineStr)(),cq2.LaTeX))==EOF) /*here is written current line*/
+           {
+	   if((i=fputs((*aLineStr)(),cq2.LaTeX))==EOF) /* Here is written the current line. */
 			{
 			RunError(0x20,"");
 			}
+           }
 	 }
 
 		// Is it possible to expand the tabbing enviroment?
