@@ -349,6 +349,8 @@ void ShowHelp(void)
 	  "\n         \"852\"(ISO8), \"866\"(Russ), \"895\"(Kamenicky), \"1250\"(Win),"
 	  "\n         \"1251\"(WinRuss), \"ISO8859_1\", \"ISO8859-2\", \"KOI8R\", \"UTF8\"."
 	  "\n   -cp-styles   Turn on special styles for codepages."
+	  "\n   -CurrentFontSet  Change codepage for a current font."
+	  "\n               \"Magical\" WP's codepage 12."
 	  "\n   -epsfig      %cUse style epsfig.sty for PostScript images."
 	  "\n   -extract-images %sImages will be extracted into separate files."
 	  "\n   -fancyhdr    Use package fancyhdr.sty for headers and footers"
@@ -839,7 +841,6 @@ EmptyInput:
     }
   logg = NULL;
 
-
 	/* Delete auxillary files */
 #ifdef _has_MemStreams  
   if(bp_strip!=NULL) {free(bp_strip);bp_strip=NULL;}
