@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.91"
-#define VersionDate	"6 Jul 2020"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.92"
+#define VersionDate	"11 Oct 2020"  /* day (space) month (space) full year */
 
 #ifndef false
  #define  false          0
@@ -81,8 +81,6 @@ extern const TStyleOpCl StyleOpCl2[];
 extern const TStyleOpCl StyleOpCl3[];
 extern const TStyleOpCl *StyleOpCl;
 
-extern char** UserWPCharSet;
-
 
 /* functions of wp2lfuti.c */
 int AbsolutePath(const char *TestedPath);
@@ -197,6 +195,9 @@ public: long StartValue;	///< Percentor starts from this.
 #define TAB_POS_SIZE 40
 
 class CpTranslator;
+
+extern CpTranslator *UserWPCharSet;
+
 class TconvertedPass1
   {
 public:
@@ -285,7 +286,6 @@ struct RGBQuad
 #define KOI8R		8
 #define UTF8		16384
 
-class CpTranslator;
 const char *Ext_chr_str(WORD char_code, TconvertedPass1 *cq, CpTranslator *ConvertCP=NULL);
 
 typedef enum {aExtraLarge=0, aVeryLarge1=1, aLarge=2, aSmall=3, aFine=4,
@@ -531,6 +531,14 @@ void UpdateFigDir(void);
 void Sys_Variable(void);
 void PrintPackageList(void);
 
+typedef struct
+{
+  const char	*Name;
+  WORD		Id;
+} OutCodePage;
+
+extern const OutCodePage OutCodepages[11];
+
 
 #ifndef __Have_stricmp
  #ifdef __Have_strcasecmp
